@@ -139,10 +139,10 @@ text_width (HTMLPainter *painter, PangoFontDescription *desc, const gchar *text,
 
 	if (pi && glyphs) {
 		GList *list;
-		int i;
-		for (list = glyphs, i = 0; list; list = list->next->next, i++) {
+		gint i;
+		for (list = glyphs; list; list = list->next->next) {
 			PangoGlyphString *str = (PangoGlyphString *) list->data;
-			for (i=0; i < str->num_glyphs; i ++)
+			for (i=0; i < str->num_glyphs; i++)
 				width += str->glyphs [i].geometry.width;
 		}
 	}
@@ -197,7 +197,7 @@ text_size (HTMLPainter *painter, PangoFontDescription *desc, const gchar *text,
 
 			c_text = g_utf8_offset_to_pointer (c_text, str->num_glyphs);
 			if (*text == '\t')
-				c_text ++;
+				c_text++;
 			c_bytes = c_text - text;
 		}
 	}
@@ -285,7 +285,7 @@ html_painter_get_type (void)
 
 void
 html_painter_begin (HTMLPainter *painter,
-		    int x1, int y1, int x2, int y2)
+		    gint x1, gint y1, gint x2, gint y2)
 {
 	g_return_if_fail (painter != NULL);
 	g_return_if_fail (HTML_IS_PAINTER (painter));
@@ -388,8 +388,7 @@ get_font_info (HTMLPainter       *painter,
 	}
 }
 
-
-static int
+static gint
 get_space_width (HTMLPainter       *painter,
 		 HTMLTextPangoInfo *pi)
 {
@@ -529,12 +528,12 @@ html_replace_tabs (const gchar *text, gchar *translated, guint bytes)
 	tt = translated;
 
 	do {
-		tab = memchr (t, (unsigned char) '\t', bytes - (t - text));
+		tab = memchr (t, (guchar) '\t', bytes - (t - text));
 		if (tab) {
 			strncpy (tt, t, tab - t);
 			tt += tab - t;
 			*tt = ' ';
-			tt ++;
+			tt++;
 			t = tab + 1;
 		} else
 			strncpy (tt, t, bytes - (t - text));
@@ -571,8 +570,8 @@ html_painter_draw_entries (HTMLPainter *painter, gint x, gint y,
 	const gchar *tab, *c_text;
 	gint bytes;
 	GList *gl;
-	int first_item_offset = -1;
-	int space_width = -1;
+	gint first_item_offset = -1;
+	gint space_width = -1;
 
 	g_return_if_fail (painter != NULL);
 	g_return_if_fail (HTML_IS_PAINTER (painter));
@@ -580,7 +579,7 @@ html_painter_draw_entries (HTMLPainter *painter, gint x, gint y,
 	c_text = text;
 	bytes = g_utf8_offset_to_pointer (text, len) - text;
 	gl = glyphs;
-	tab = memchr (c_text, (unsigned char) '\t', bytes);
+	tab = memchr (c_text, (guchar) '\t', bytes);
 
 	/* We iterate through the string by tabs and non-tab segments, skipping over
 	 * the tabs and drawing the non-tab segments.
@@ -616,7 +615,7 @@ html_painter_draw_entries (HTMLPainter *painter, gint x, gint y,
 				line_offset += 8 - (line_offset % 8);
 			}
 
-			tab = memchr (c_text + 1, (unsigned char) '\t', bytes - 1);
+			tab = memchr (c_text + 1, (guchar) '\t', bytes - 1);
 		} else {
 			x += html_painter_pango_to_engine (painter, (* HP_CLASS (painter)->draw_glyphs) (painter, x, y, item, gl->data, NULL, NULL));
 
@@ -631,8 +630,8 @@ html_painter_draw_entries (HTMLPainter *painter, gint x, gint y,
 	}
 }
 
-int
-html_painter_draw_glyphs (HTMLPainter *painter, int x, int y, PangoItem *item, PangoGlyphString *glyphs, GdkColor *fg, GdkColor *bg)
+gint
+html_painter_draw_glyphs (HTMLPainter *painter, gint x, gint y, PangoItem *item, PangoGlyphString *glyphs, GdkColor *fg, GdkColor *bg)
 {
 	return (* HP_CLASS (painter)->draw_glyphs) (painter, x, y, item, glyphs, fg, bg);
 }
@@ -820,7 +819,7 @@ html_painter_get_pixel_size (HTMLPainter *painter)
 }
 
 gint
-html_painter_draw_spell_error (HTMLPainter *painter, int x, int y, int width)
+html_painter_draw_spell_error (HTMLPainter *painter, gint x, gint y, gint width)
 {
 	return (* HP_CLASS (painter)->draw_spell_error) (painter, x, y, width);
 }
@@ -915,19 +914,19 @@ guint
 html_painter_get_block_cite_width (HTMLPainter *painter, GtkHTMLFontStyle style, HTMLFontFace *face, HTMLDirection dir)
 {
 	HTMLFont *font = html_font_manager_get_font (&painter->font_manager, face, style);
-	return dir == HTML_DIRECTION_RTL ? font->cite_width_rtl : font->cite_width_ltr ;
+	return dir == HTML_DIRECTION_RTL ? font->cite_width_rtl : font->cite_width_ltr;
 }
 
 guint
 html_painter_get_page_width (HTMLPainter *painter, HTMLEngine *e)
 {
-	return 	(* HP_CLASS (painter)->get_page_width) (painter, e);
+	return	(* HP_CLASS (painter)->get_page_width) (painter, e);
 }
 
 guint
 html_painter_get_page_height (HTMLPainter *painter, HTMLEngine *e)
 {
-	return 	(* HP_CLASS (painter)->get_page_height) (painter, e);
+	return	(* HP_CLASS (painter)->get_page_height) (painter, e);
 }
 
 /**
@@ -1019,7 +1018,7 @@ html_painter_text_itemize_and_prepare_glyphs (HTMLPainter *painter, PangoFontDes
 			end = g_utf8_offset_to_pointer (text, item->num_chars);
 			*glyphs = html_get_glyphs_non_tab (*glyphs, item, i, text, end - text, item->num_chars);
 			text = end;
-			i ++;
+			i++;
 		}
 		*glyphs = g_list_reverse (*glyphs);
 		g_list_free (items);
