@@ -47,7 +47,7 @@ static HTMLObjectClass *parent_class = NULL;
 
 static void    clear_glyph_items (HTMLTextSlave *slave);
 
-char *
+gchar *
 html_text_slave_get_text (HTMLTextSlave *slave)
 {
 	if (!slave->charStart)
@@ -58,7 +58,7 @@ html_text_slave_get_text (HTMLTextSlave *slave)
 
 /* Split this TextSlave at the specified offset.  */
 static void
-split (HTMLTextSlave *slave, guint offset, int skip, char *start_pointer)
+split (HTMLTextSlave *slave, guint offset, gint skip, gchar *start_pointer)
 {
 	HTMLObject *obj;
 	HTMLObject *new;
@@ -113,7 +113,7 @@ hts_update_asc_dsc (HTMLPainter *painter, PangoItem *item, gint *asc, gint *dsc)
 	pango_font_metrics_unref (pfm);
 }
 
-static int
+static gint
 hts_calc_width (HTMLTextSlave *slave, HTMLPainter *painter, gint *asc, gint *dsc)
 {
 	/*HTMLText *text = slave->owner;
@@ -129,7 +129,7 @@ hts_calc_width (HTMLTextSlave *slave, HTMLPainter *painter, gint *asc, gint *dsc
 	GSList *cur, *gilist = html_text_slave_get_glyph_items (slave, painter);
 	PangoLanguage *language = NULL;
 	PangoFont *font = NULL;
-	int width = 0;
+	gint width = 0;
 
 	if (asc)
 		*asc = html_painter_engine_to_pango (painter,
@@ -319,8 +319,8 @@ html_text_slave_remove_leading_space (HTMLTextSlave *slave, HTMLPainter *painter
 	if (*begin == ' ' && could_remove_leading_space (slave, lineBegin)) {
 		begin = g_utf8_next_char (begin);
 		slave->charStart = begin;
-		slave->posStart ++;
-		slave->posLen --;
+		slave->posStart++;
+		slave->posLen--;
 	}
 
 	return begin;
@@ -335,7 +335,7 @@ html_text_slave_get_nb_width (HTMLTextSlave *slave, HTMLPainter *painter, gboole
 }
 
 /*
- * offset: current position - char offset
+ * offset: current position - gchar offset
  * s: current position - string pointer
  * ii: current position - index of item
  * io: current position - offset within item
@@ -404,7 +404,7 @@ hts_fit_line (HTMLObject *o, HTMLPainter *painter,
 
 		if (io == 0 && slave->owner->text [pi->entries [ii].glyph_item.item->offset]  == '\t') {
 			GtkHTMLFontStyle font_style;
-			char *face;
+			gchar *face;
 			gint skip = 8 - (line_offset % 8);
 
 			if (HTML_IS_PLAIN_PAINTER (painter)) {
@@ -419,13 +419,13 @@ hts_fit_line (HTMLObject *o, HTMLPainter *painter,
 				= skip*html_painter_get_space_width (painter, font_style, face) * PANGO_SCALE;
 			line_offset += skip;
 		} else {
-			line_offset ++;
+			line_offset++;
 		}
 		w += pi->entries [ii].widths [io];
 
 		html_text_pi_forward (pi, &ii, &io);
 		s = g_utf8_next_char (s);
-		offset ++;
+		offset++;
 	}
 
 	if (offset == slave->posStart + slave->posLen && (widthLeft >= w || force_fit)) {
@@ -493,7 +493,7 @@ html_get_glyphs_non_tab (GList *glyphs, PangoItem *item, gint ii, const gchar *t
 {
 	gchar *tab;
 
-	while ((tab = memchr (text, (unsigned char) '\t', bytes))) {
+	while ((tab = memchr (text, (guchar) '\t', bytes))) {
 		gint c_bytes = tab - text;
 		if (c_bytes > 0)
 			glyphs = get_glyphs_base_text (glyphs, item, ii, text, c_bytes);
@@ -513,18 +513,18 @@ html_get_glyphs_non_tab (GList *glyphs, PangoItem *item, gint ii, const gchar *t
  */
 
 static GSList *
-reorder_glyph_items (GSList *glyph_items, int n_items)
+reorder_glyph_items (GSList *glyph_items, gint n_items)
 {
 	GSList *tmp_list, *level_start_node;
-	int i, level_start_i;
-	int min_level = G_MAXINT;
+	gint i, level_start_i;
+	gint min_level = G_MAXINT;
 	GSList *result = NULL;
 
 	if (n_items == 0)
 		return NULL;
 
 	tmp_list = glyph_items;
-	for (i = 0; i < n_items; i ++) {
+	for (i = 0; i < n_items; i++) {
 		HTMLTextSlaveGlyphItem *gi = tmp_list->data;
 
 		min_level = MIN (min_level, gi->glyph_item.item->analysis.level);
@@ -535,7 +535,7 @@ reorder_glyph_items (GSList *glyph_items, int n_items)
 	level_start_i = 0;
 	level_start_node = glyph_items;
 	tmp_list = glyph_items;
-	for (i = 0; i < n_items; i ++) {
+	for (i = 0; i < n_items; i++) {
 		HTMLTextSlaveGlyphItem *gi= tmp_list->data;
 
 		if (gi->glyph_item.item->analysis.level == min_level) {
@@ -568,16 +568,16 @@ reorder_glyph_items (GSList *glyph_items, int n_items)
 }
 
 static GSList *
-get_glyph_items_in_range (HTMLTextSlave *slave, HTMLPainter *painter, int start_offset, int len)
+get_glyph_items_in_range (HTMLTextSlave *slave, HTMLPainter *painter, gint start_offset, gint len)
 {
 	HTMLTextPangoInfo *pi = html_text_get_pango_info (slave->owner, painter);
-	int i, offset, end_offset, n_items = 0;
+	gint i, offset, end_offset, n_items = 0;
 	GSList *glyph_items = NULL;
 
 	start_offset += slave->posStart;
 	end_offset = start_offset + len;
 
-	for (offset = 0, i = 0; i < pi->n; i ++) {
+	for (offset = 0, i = 0; i < pi->n; i++) {
 		PangoItem *item = pi->entries [i].glyph_item.item;
 
 		/* do item and slave overlap? */
@@ -592,7 +592,7 @@ get_glyph_items_in_range (HTMLTextSlave *slave, HTMLPainter *painter, int start_
 			if (start_offset > offset) {
 				/* need to cut the beginning of current glyph item */
 				PangoGlyphItem *tmp_gi;
-				int split_index;
+				gint split_index;
 
 				glyph_item->type = HTML_TEXT_SLAVE_GLYPH_ITEM_CREATED;
 				glyph_item->widths = NULL;
@@ -611,7 +611,7 @@ get_glyph_items_in_range (HTMLTextSlave *slave, HTMLPainter *painter, int start_
 			if (offset + item->num_chars > end_offset) {
 				/* need to cut the ending of current glyph item */
 				PangoGlyphItem tmp_gi1, *tmp_gi2;
-				int split_index;
+				gint split_index;
 
 				if (glyph_item->type == HTML_TEXT_SLAVE_GLYPH_ITEM_PARENTAL) {
 					tmp_gi1.item = pango_item_copy (glyph_item->glyph_item.item);
@@ -637,7 +637,7 @@ get_glyph_items_in_range (HTMLTextSlave *slave, HTMLPainter *painter, int start_
 			}
 
 			glyph_items = g_slist_prepend (glyph_items, glyph_item);
-			n_items ++;
+			n_items++;
 		}
 
 		if (offset + item->num_chars >= end_offset)
@@ -670,9 +670,9 @@ html_text_slave_get_glyph_items (HTMLTextSlave *slave, HTMLPainter *painter)
 }
 
 static gboolean
-calc_glyph_range_size (HTMLText *text, PangoGlyphItem *glyph_item, int start_index, int end_index, int *x_offset, int *width, int *asc, int *height)
+calc_glyph_range_size (HTMLText *text, PangoGlyphItem *glyph_item, gint start_index, gint end_index, gint *x_offset, gint *width, gint *asc, gint *height)
 {
-	int isect_start, isect_end;
+	gint isect_start, isect_end;
 
 	isect_start = MAX (glyph_item->item->offset, start_index);
 	isect_end = MIN (glyph_item->item->offset + glyph_item->item->length, end_index);
@@ -684,7 +684,7 @@ calc_glyph_range_size (HTMLText *text, PangoGlyphItem *glyph_item, int start_ind
 
 	if (isect_start <= isect_end) {
 		PangoRectangle log_rect;
-		int start_x, end_x;
+		gint start_x, end_x;
 
 		pango_glyph_string_index_to_x (glyph_item->glyphs,
 					       text->text + glyph_item->item->offset,
@@ -739,10 +739,10 @@ draw_text (HTMLTextSlave *self,
 	HTMLObject *obj;
 	HTMLText *text = self->owner;
 	GSList *cur;
-	int run_width;
-	int selection_start_index = 0;
-	int selection_end_index = 0;
-	int isect_start, isect_end;
+	gint run_width;
+	gint selection_start_index = 0;
+	gint selection_end_index = 0;
+	gint isect_start, isect_end;
 	gboolean selection;
 	GdkColor selection_fg, selection_bg;
 	HTMLEngine *e = NULL;
@@ -782,7 +782,7 @@ draw_text (HTMLTextSlave *self,
 	for (cur = html_text_slave_get_glyph_items (self, p); cur; cur = cur->next) {
 		HTMLTextSlaveGlyphItem *gi = (HTMLTextSlaveGlyphItem *) cur->data;
 		GList *cur_se;
-		int cur_width;
+		gint cur_width;
 
 		if (e)
 			html_painter_set_pen (p, &html_colorset_get_color_allocated (e->settings->color_set,
@@ -791,12 +791,12 @@ draw_text (HTMLTextSlave *self,
 						      obj->y + ty + get_ys (text, p), gi->glyph_item.item, gi->glyph_item.glyphs, NULL, NULL);
 
 		if (selection) {
-			int start_x, width, asc, height;
-			int cx, cy, cw, ch;
+			gint start_x, width, asc, height;
+			gint cx, cy, cw, ch;
 
 			if (calc_glyph_range_size (text, &gi->glyph_item, selection_start_index, selection_end_index, &start_x, &width, &asc, &height) && width > 0) {
 				html_painter_get_clip_rectangle (p, &cx, &cy, &cw, &ch);
-/* 				printf ("run_width; %d start_x %d index %d\n", run_width, start_x, selection_start_index); */
+/*				printf ("run_width; %d start_x %d index %d\n", run_width, start_x, selection_start_index); */
 				html_painter_set_clip_rectangle (p,
 							obj->x + tx + html_painter_pango_to_engine (p, run_width + start_x),
 							obj->y + ty + get_ys (text, p) - html_painter_pango_to_engine (p, asc),
@@ -821,11 +821,11 @@ draw_text (HTMLTextSlave *self,
 			mi = MIN (se->off + se->len, self->posStart + self->posLen);
 
 			if (ma < mi) {
-				int width, height, asc, start_x;
+				gint width, height, asc, start_x;
 
 				gchar *end;
 				gchar *start;
-				int se_start_index, se_end_index;
+				gint se_start_index, se_end_index;
 
 				start = html_text_get_text (text, ma);
 				end = g_utf8_offset_to_pointer (start, mi - ma);
@@ -836,7 +836,7 @@ draw_text (HTMLTextSlave *self,
 				if (calc_glyph_range_size (text, &gi->glyph_item, se_start_index, se_end_index, &start_x, &width, &asc, &height)) {
 					html_painter_set_pen (p, &html_colorset_get_color_allocated (e->settings->color_set,
 												     p, HTMLSpellErrorColor)->color);
-				        /* printf ("spell error: %s\n", html_text_get_text (slave->owner, off)); */
+					/* printf ("spell error: %s\n", html_text_get_text (slave->owner, off)); */
 
 					html_painter_draw_spell_error (p, obj->x + tx + html_painter_pango_to_engine (p, run_width + start_x),
 								       obj->y + ty + get_ys (self->owner, p), html_painter_pango_to_engine (p, width));
@@ -955,11 +955,11 @@ static gint
 calc_offset (HTMLTextSlave *slave, HTMLPainter *painter, gint x)
 {
 	GSList *cur, *glyphs = html_text_slave_get_glyph_items (slave, painter);
-	int width = 0, offset = html_object_get_direction (HTML_OBJECT (slave->owner)) == HTML_DIRECTION_RTL ? slave->posLen : 0;
+	gint width = 0, offset = html_object_get_direction (HTML_OBJECT (slave->owner)) == HTML_DIRECTION_RTL ? slave->posLen : 0;
 	PangoItem *item = NULL;
 
 	if (glyphs) {
-		int i = 0;
+		gint i = 0;
 
 		for (cur = glyphs; cur; cur = cur->next) {
 			HTMLTextSlaveGlyphItem *gi = (HTMLTextSlaveGlyphItem *) cur->data;
@@ -975,16 +975,16 @@ calc_offset (HTMLTextSlave *slave, HTMLPainter *painter, gint x)
 
 			if (item->analysis.level % 2 == 0) {
 				/* LTR */
-				for (i = 0; i < item->num_chars; i ++) {
+				for (i = 0; i < item->num_chars; i++) {
 					if (x < html_painter_pango_to_engine (painter, width + gi->widths [i] / 2))
 						goto done;
 					width += gi->widths [i];
 				}
 			} else {
 				/* RTL */
-				for (i = item->num_chars - 1; i >= 0; i --) {
+				for (i = item->num_chars - 1; i >= 0; i--) {
 					if (x < html_painter_pango_to_engine (painter, width + gi->widths [i] / 2)) {
-						i ++;
+						i++;
 						goto done;
 					}
 					width += gi->widths [i];
@@ -1001,7 +1001,7 @@ calc_offset (HTMLTextSlave *slave, HTMLPainter *painter, gint x)
 		}
 	}
 
-/* 	printf ("offset %d\n", offset); */
+/*	printf ("offset %d\n", offset); */
 
 	return offset;
 }
@@ -1139,7 +1139,7 @@ html_text_slave_new (HTMLText *owner, guint posStart, guint posLen)
 }
 
 static gboolean
-html_text_slave_is_index_in_glyph (HTMLTextSlave *slave, HTMLTextSlave *next_slave, GSList *cur, int index, PangoItem *item)
+html_text_slave_is_index_in_glyph (HTMLTextSlave *slave, HTMLTextSlave *next_slave, GSList *cur, gint index, PangoItem *item)
 {
 	if (item->analysis.level % 2 == 0) {
 		/* LTR */
@@ -1161,15 +1161,15 @@ html_text_slave_is_index_in_glyph (HTMLTextSlave *slave, HTMLTextSlave *next_sla
 }
 
 static HTMLTextSlaveGlyphItem *
-html_text_slave_get_glyph_item_at_offset (HTMLTextSlave *slave, HTMLPainter *painter, int offset, HTMLTextSlaveGlyphItem **prev, HTMLTextSlaveGlyphItem **next, int *start_width, int *index_out)
+html_text_slave_get_glyph_item_at_offset (HTMLTextSlave *slave, HTMLPainter *painter, gint offset, HTMLTextSlaveGlyphItem **prev, HTMLTextSlaveGlyphItem **next, gint *start_width, gint *index_out)
 {
 	HTMLTextSlaveGlyphItem *rv = NULL;
 	HTMLTextSlaveGlyphItem *prev_gi, *next_gi;
 	HTMLTextSlave *next_slave = HTML_OBJECT (slave)->next && HTML_IS_TEXT_SLAVE (HTML_OBJECT (slave)->next) ? HTML_TEXT_SLAVE (HTML_OBJECT (slave)->next) : NULL;
 	GSList *cur;
-	int index;
+	gint index;
 
-	prev_gi = next_gi = NULL;
+	next_gi = NULL;
 
 	index = g_utf8_offset_to_pointer (html_text_slave_get_text (slave), offset) - slave->owner->text;
 	if (index_out)
@@ -1213,7 +1213,7 @@ html_text_slave_get_glyph_item_at_offset (HTMLTextSlave *slave, HTMLPainter *pai
 static gboolean
 html_text_slave_gi_left_edge (HTMLTextSlave *slave, HTMLCursor *cursor, HTMLTextSlaveGlyphItem *gi)
 {
-	int old_offset = cursor->offset;
+	gint old_offset = cursor->offset;
 
 	if (gi->glyph_item.item->analysis.level % 2 == 0) {
 		/* LTR */
@@ -1233,7 +1233,7 @@ html_text_slave_gi_left_edge (HTMLTextSlave *slave, HTMLCursor *cursor, HTMLText
 static gboolean
 html_text_slave_gi_right_edge (HTMLTextSlave *slave, HTMLCursor *cursor, HTMLTextSlaveGlyphItem *gi)
 {
-	int old_offset = cursor->offset;
+	gint old_offset = cursor->offset;
 
 	if (gi->glyph_item.item->analysis.level % 2 == 0) {
 		/* LTR */
@@ -1254,7 +1254,7 @@ static gboolean
 html_text_slave_cursor_right_one (HTMLTextSlave *slave, HTMLPainter *painter, HTMLCursor *cursor)
 {
 	HTMLTextSlaveGlyphItem *prev, *next;
-	int index;
+	gint index;
 	HTMLTextSlaveGlyphItem *gi = html_text_slave_get_glyph_item_at_offset (slave, painter, cursor->offset - slave->posStart, &prev, &next, NULL, &index);
 
 	if (!gi)
@@ -1263,16 +1263,16 @@ html_text_slave_cursor_right_one (HTMLTextSlave *slave, HTMLPainter *painter, HT
 	if (gi->glyph_item.item->analysis.level % 2 == 0) {
 		/* LTR */
 		if (index < gi->glyph_item.item->offset + gi->glyph_item.item->length) {
-			cursor->offset ++;
-			cursor->position ++;
+			cursor->offset++;
+			cursor->position++;
 
 			return TRUE;
 		}
 	} else {
 		/* RTL */
 		if (index > gi->glyph_item.item->offset && index <= gi->glyph_item.item->offset + gi->glyph_item.item->length) {
-			cursor->offset --;
-			cursor->position --;
+			cursor->offset--;
+			cursor->position--;
 
 			return TRUE;
 		}
@@ -1282,12 +1282,12 @@ html_text_slave_cursor_right_one (HTMLTextSlave *slave, HTMLPainter *painter, HT
 		if (html_text_slave_gi_left_edge (slave, cursor, next)) {
 			if (next->glyph_item.item->analysis.level % 2 == 0) {
 				/* LTR */
-				cursor->offset ++;
-				cursor->position ++;
+				cursor->offset++;
+				cursor->position++;
 			} else {
 				/* RTL */
-				cursor->offset --;
-				cursor->position --;
+				cursor->offset--;
+				cursor->position--;
 			}
 
 			return TRUE;
@@ -1314,11 +1314,11 @@ static gboolean
 html_text_slave_cursor_left_one (HTMLTextSlave *slave, HTMLPainter *painter, HTMLCursor *cursor)
 {
 	HTMLTextSlaveGlyphItem *prev, *next;
-	int index;
+	gint index;
 	HTMLObject *prev_obj = HTML_OBJECT (slave->owner)->prev;
 	HTMLTextSlaveGlyphItem *gi = html_text_slave_get_glyph_item_at_offset (slave, painter, cursor->offset - slave->posStart, &prev, &next, NULL, &index);
 
-/* 	printf ("gi: %p item num chars: %d\n", gi, gi ? gi->glyph_item.item->num_chars : -1); */
+/*	printf ("gi: %p item num chars: %d\n", gi, gi ? gi->glyph_item.item->num_chars : -1); */
 
 	if (!gi)
 		return FALSE;
@@ -1326,16 +1326,16 @@ html_text_slave_cursor_left_one (HTMLTextSlave *slave, HTMLPainter *painter, HTM
 	if (gi->glyph_item.item->analysis.level % 2 == 0) {
 		/* LTR */
 		if (index - gi->glyph_item.item->offset > 1 || (!prev && !prev_obj && index - gi->glyph_item.item->offset > 0)) {
-			cursor->offset --;
-			cursor->position --;
+			cursor->offset--;
+			cursor->position--;
 
 			return TRUE;
 		}
 	} else {
 		/* RTL */
 		if (index < gi->glyph_item.item->offset + gi->glyph_item.item->length) {
-			cursor->offset ++;
-			cursor->position ++;
+			cursor->offset++;
+			cursor->position++;
 
 			return TRUE;
 		}
@@ -1346,13 +1346,13 @@ html_text_slave_cursor_left_one (HTMLTextSlave *slave, HTMLPainter *painter, HTM
 			if (prev->glyph_item.item->analysis.level % 2 == 0) {
 				/* LTR */
 				if (index - gi->glyph_item.item->offset == 0) {
-					cursor->offset --;
-					cursor->position --;
+					cursor->offset--;
+					cursor->position--;
 				}
 			} else {
 				/* RTL */
-				cursor->offset ++;
-				cursor->position ++;
+				cursor->offset++;
+				cursor->position++;
 			}
 
 			return TRUE;
@@ -1379,8 +1379,8 @@ static gboolean
 html_text_slave_get_left_edge (HTMLTextSlave *slave, HTMLPainter *painter, HTMLCursor *cursor)
 {
 	HTMLTextPangoInfo *pi = html_text_get_pango_info (slave->owner, painter);
-	int old_offset = cursor->offset;
-	int old_position = cursor->position;
+	gint old_offset = cursor->offset;
+	gint old_position = cursor->position;
 
 	cursor->offset = html_text_slave_get_left_edge_offset (slave, painter);
 
@@ -1400,8 +1400,8 @@ static gboolean
 html_text_slave_get_right_edge (HTMLTextSlave *slave, HTMLPainter *painter, HTMLCursor *cursor)
 {
 	HTMLTextPangoInfo *pi = html_text_get_pango_info (slave->owner, painter);
-	int old_offset = cursor->offset;
-	int old_position = cursor->position;
+	gint old_offset = cursor->offset;
+	gint old_position = cursor->position;
 
 	cursor->offset = html_text_slave_get_right_edge_offset (slave, painter);
 
@@ -1457,27 +1457,27 @@ void
 html_text_slave_get_cursor_base (HTMLTextSlave *slave, HTMLPainter *painter, guint offset, gint *x, gint *y)
 {
 	HTMLTextSlaveGlyphItem *gi;
-	int index, start_width;
+	gint index, start_width;
 
 	html_object_calc_abs_position (HTML_OBJECT (slave), x, y);
 
-	gi = html_text_slave_get_glyph_item_at_offset (slave, painter, (int) offset, NULL, NULL, &start_width, &index);
+	gi = html_text_slave_get_glyph_item_at_offset (slave, painter, (gint) offset, NULL, NULL, &start_width, &index);
 
-/* 	printf ("gi: %p index: %d start_width: %d item indexes %d %d\n", */
-/* 		gi, index, start_width, gi ? gi->glyph_item.item->offset : -1, */
-/* 		gi ? gi->glyph_item.item->offset + gi->glyph_item.item->length : -1); */
+/*	printf ("gi: %p index: %d start_width: %d item indexes %d %d\n", */
+/*		gi, index, start_width, gi ? gi->glyph_item.item->offset : -1, */
+/*		gi ? gi->glyph_item.item->offset + gi->glyph_item.item->length : -1); */
 
 	if (gi) {
-		int start_x;
+		gint start_x;
 
 		if (calc_glyph_range_size (slave->owner, &gi->glyph_item, index, index, &start_x, NULL, NULL, NULL) && x) {
-/* 			printf ("start_width: %d start_x: %d\n", start_width, start_x); */
+/*			printf ("start_width: %d start_x: %d\n", start_width, start_x); */
 			*x += html_painter_pango_to_engine (painter, start_width + start_x);
 		}
 	}
 }
 
-int
+gint
 html_text_slave_get_left_edge_offset (HTMLTextSlave *slave, HTMLPainter *painter)
 {
 	GSList *gis = html_text_slave_get_glyph_items (slave, painter);
@@ -1502,7 +1502,7 @@ html_text_slave_get_left_edge_offset (HTMLTextSlave *slave, HTMLPainter *painter
 	}
 }
 
-int
+gint
 html_text_slave_get_right_edge_offset (HTMLTextSlave *slave, HTMLPainter *painter)
 {
 	GSList *gis = html_text_slave_get_glyph_items (slave, painter);
